<!DOCTYPE TS><TS>
<defaultcodec></defaultcodec>
<context>
    <name>AdvSearch</name>
    <message>
        <source>Cannot execute pure negative query. Please enter common terms in the &apos;any words&apos; field</source>
        <translation type="unfinished">Неможна виконати суцільно негативний запит.  Будь ласка, введіть загальні терміни у полі &quot;будь-які слова&quot;</translation>
    </message>
    <message>
        <source>All clauses</source>
        <translation>Всі поля</translation>
    </message>
    <message>
        <source>Any clause</source>
        <translation>Будь-яке поле</translation>
    </message>
    <message>
        <source>Cannot execute pure negativequery. Please enter common terms in the &apos;any words&apos; field</source>
        <translation type="obsolete">Неможна виконати суцільно негативний запит.  Будь ласка, введіть загальні терміни у полі &quot;будь-які слова&quot;</translation>
    </message>
    <message>
        <source>texts</source>
        <translation>тексти</translation>
    </message>
    <message>
        <source>spreadsheets</source>
        <translation>таблиці</translation>
    </message>
    <message>
        <source>presentations</source>
        <translation>презентації</translation>
    </message>
    <message>
        <source>media</source>
        <translation>мультимедіа</translation>
    </message>
    <message>
        <source>messages</source>
        <translation>повідомлення</translation>
    </message>
    <message>
        <source>other</source>
        <translation>інше</translation>
    </message>
</context>
<context>
    <name>AdvSearchBase</name>
    <message>
        <source>Advanced search</source>
        <translation>Складний пошук</translation>
    </message>
    <message>
        <source>Search for files&lt;br&gt;having all of:</source>
        <translation type="obsolete">Шукати&lt;br&gt;файли:</translation>
    </message>
    <message>
        <source>All non blank fields will be combined with AND conjunctions. &lt;br&gt;All fields except &quot;exact phrase&quot; can accept a mix of simple words, and phrases enclosed in double quotes.</source>
        <translation type="obsolete">Вісі непусті поля будуть поєднані логічним ТА.&lt;br&gt;Всі поля, окрім &quot;точної фрази&quot;, приймають суміш простих слів та фраз у подвійних лапках.</translation>
    </message>
    <message>
        <source>All of these</source>
        <translation type="obsolete">з усіма словами</translation>
    </message>
    <message>
        <source>Enter words, and/or quoted phrases.</source>
        <translation type="obsolete">Введіть слова та/або фрази у лапках.</translation>
    </message>
    <message>
        <source>This exact phrase</source>
        <translation type="obsolete">із точною фразою</translation>
    </message>
    <message>
        <source>Enter words.</source>
        <translation type="obsolete">Введіть слова.</translation>
    </message>
    <message>
        <source>Any of these</source>
        <translation type="obsolete">з усіма словами</translation>
    </message>
    <message>
        <source>None of these</source>
        <translation type="obsolete">без цих слів</translation>
    </message>
    <message>
        <source>File name matching</source>
        <translation type="obsolete">з ім&apos;ям</translation>
    </message>
    <message>
        <source>Enter file name. * and ? are wildcards.</source>
        <translation type="obsolete">Введіть ім&apos;я файлу. * та ? є шаблонами.</translation>
    </message>
    <message>
        <source>Restrict file types</source>
        <translation>Обмежити типи файлів</translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation>Зберегти як типові</translation>
    </message>
    <message>
        <source>Searched file types</source>
        <translation>Бажані</translation>
    </message>
    <message>
        <source>All ----&gt;</source>
        <translation>Всі -----&gt;</translation>
    </message>
    <message>
        <source>Sel -----&gt;</source>
        <translation>Виб -----&gt;</translation>
    </message>
    <message>
        <source>&lt;----- Sel</source>
        <translation>&lt;----- Виб</translation>
    </message>
    <message>
        <source>&lt;----- All</source>
        <translation>&lt;----- Всі</translation>
    </message>
    <message>
        <source>Ignored file types</source>
        <translation>Ігноровані</translation>
    </message>
    <message>
        <source>Enter top directory for search</source>
        <translation>Шукати тільки у каталозі</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Перегляд</translation>
    </message>
    <message>
        <source>Restrict results to files in subtree:</source>
        <translation>Обмежити пошук по файлах з піддерева:</translation>
    </message>
    <message>
        <source>Start Search</source>
        <translation>Шукати</translation>
    </message>
    <message>
        <source>Dismiss</source>
        <translation type="obsolete">Відмінити</translation>
    </message>
    <message>
        <source>Search for &lt;br&gt;documents&lt;br&gt;satisfying:</source>
        <translation>Шукати&lt;br&gt;документи,&lt;/br&gt;що задовільняють:</translation>
    </message>
    <message>
        <source>All non blank fields will be combined with OR or AND conjunctions. &lt;br&gt;&quot;Any&quot; &quot;All&quot; and &quot;None&quot; field types can accept a mix of simple words, and phrases enclosed in double quotes.&lt;br&gt;Fields with no data are ignored.</source>
        <translation type="obsolete">Всі непусті поля буде об&apos;єднано за допомогою АБО або ТА.&lt;br&gt;Поля типу &quot;будь-які слова&quot;, &quot;усі слова&quot; та &quot;без цих слів&quot; приймають слова та фрази у подвійних лапках.&lt;br&gt;Поля без даних не беруться до уваги.</translation>
    </message>
    <message>
        <source>Delete clause</source>
        <translation>Прибрати поле</translation>
    </message>
    <message>
        <source>Add clause</source>
        <translation>Додати поле</translation>
    </message>
    <message>
        <source>Check this to enable filtering on file types</source>
        <translation>Використовувати фільтрацію по типах файлів</translation>
    </message>
    <message>
        <source>By categories</source>
        <translation>По категоріях</translation>
    </message>
    <message>
        <source>Check this to use file categories instead of raw mime types</source>
        <translation>Використовувати категорії замість типів MIME</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>All non empty fields on the right will be combined with AND (&quot;All clauses&quot; choice) or OR (&quot;Any clause&quot; choice) conjunctions. &lt;br&gt;&quot;Any&quot; &quot;All&quot; and &quot;None&quot; field types can accept a mix of simple words, and phrases enclosed in double quotes.&lt;br&gt;Fields with no data are ignored.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Configuration problem: </source>
        <translation type="obsolete">Проблема конфіґурації: </translation>
    </message>
    <message>
        <source>No db directory in configuration</source>
        <translation>В конфігурації немає каталогу БД </translation>
    </message>
    <message>
        <source>Could not open database in </source>
        <translation>Не можу відкрити базу даних в </translation>
    </message>
    <message>
        <source>.
Click Cancel if you want to edit the configuration file before indexation starts, or Ok to let it proceed.</source>
        <translation>.
Натисніть Відміна, якщо бажаєте відредагувати конфіґурацію до початку індексування,
чи OK для продовження.</translation>
    </message>
    <message>
        <source>Configuration problem (dynconf</source>
        <translation>Проблема конфігурації (dynconf</translation>
    </message>
</context>
<context>
    <name>Preview</name>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Перегляд</translation>
    </message>
    <message>
        <source>Preview 1</source>
        <translation type="obsolete">Перегляд 1</translation>
    </message>
    <message>
        <source>&amp;Search for:</source>
        <translation>&amp;Шукати:</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Наступне</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="obsolete">Alt+N</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>&amp;Попереднє</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation type="obsolete">Alt+P</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Стерти</translation>
    </message>
    <message>
        <source>Match &amp;Case</source>
        <translation>&amp;Чутливість до реєстру</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+C</translation>
    </message>
    <message>
        <source>Cannot create temporary directory</source>
        <translation>Не можу створити тимчасову теку</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Відмінити</translation>
    </message>
    <message>
        <source>Can&apos;t turn doc into internal rep for </source>
        <translation type="obsolete">Не можу перетворити документ у внутрішній вигляд </translation>
    </message>
    <message>
        <source>Creating preview text</source>
        <translation>Створюю текст для перегляду</translation>
    </message>
    <message>
        <source>Loading preview text into editor</source>
        <translation>Завантажую текст перегляду в редактор</translation>
    </message>
    <message>
        <source>Close Tab</source>
        <translation>Закрити вкладку</translation>
    </message>
    <message>
        <source>File does not exist</source>
        <translation>Файл не існує</translation>
    </message>
    <message>
        <source>Missing helper program: </source>
        <translation>Не знайдено допоміжну програму: </translation>
    </message>
    <message>
        <source>Can&apos;t turn doc into internal representation for </source>
        <translation>Неможливо перетворити документ на внутрішнє представлення для </translation>
    </message>
</context>
<context>
    <name>PreviewBase</name>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Перегляд</translation>
    </message>
    <message>
        <source>Preview 1</source>
        <translation type="obsolete">Перегляд 1</translation>
    </message>
    <message>
        <source>&amp;Search for:</source>
        <translation type="obsolete">&amp;Шукати:</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation type="obsolete">&amp;Наступна</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="obsolete">Alt+N</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation type="obsolete">&amp;Попередня</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation type="obsolete">Alt+P</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="obsolete">Стерти</translation>
    </message>
    <message>
        <source>Match &amp;Case</source>
        <translation type="obsolete">&amp;Чутливість до реєстру</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+C</translation>
    </message>
</context>
<context>
    <name>PreviewTextEdit</name>
    <message>
        <source>Show fields</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show main text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Global parameters</source>
        <translation>Загальні параметри</translation>
    </message>
    <message>
        <source>Local parameters</source>
        <translation>Місцеві параметри</translation>
    </message>
    <message>
        <source>&lt;b&gt;Customised subtrees</source>
        <translation>&lt;b&gt;Піддерева з налаштуваннями</translation>
    </message>
    <message>
        <source>The list of subdirectories in the indexed hierarchy &lt;br&gt;where some parameters need to be redefined. Default: empty.</source>
        <translation>Список тек у індексованій ієрархії,&lt;br&gt;для яких деякі параметри потрібно змінити.  Типово: пустий.</translation>
    </message>
    <message>
        <source>&lt;i&gt;The parameters that follow are set either at the top level, if nothing&lt;br&gt;or an empty line is selected in the listbox above, or for the selected subdirectory.&lt;br&gt;You can add or remove directories by clicking the +/- buttons.</source>
        <translation>&lt;i&gt;Нижченаведені параметри змінюються або на верхньому рівні, якщо&lt;br&gt;не вибрано нічого або пустий рядок, або для вибраної теки.&lt;br&gt;Ви можете додати або прибрати теки кнопками +/-.</translation>
    </message>
    <message>
        <source>Skipped names</source>
        <translation>Пропускати назви</translation>
    </message>
    <message>
        <source>These are patterns for file or directory  names which should not be indexed.</source>
        <translation>Шаблони назв файлів або тек, які не буде індексовано.</translation>
    </message>
    <message>
        <source>Default character set</source>
        <translation>Типове кодування</translation>
    </message>
    <message>
        <source>This is the character set used for reading files which do not identify the character set internally, for example pure text files.&lt;br&gt;The default value is empty, and the value from the NLS environnement is used.</source>
        <translation>Кодування, яке буде застосовано при читанні файлів, які не вказують таке особливо (наприклад, чисто текстових файлів).&lt;br&gt;Типово невказане, тоді використовується значення з оточення (локалі).</translation>
    </message>
    <message>
        <source>Follow symbolic links</source>
        <translation>Розкривати символічні посилання</translation>
    </message>
    <message>
        <source>Follow symbolic links while indexing. The default is no, to avoid duplicate indexing</source>
        <translation>Ходити по симлінках при індексації.  Типово &quot;ні&quot; для уникнення дублікатів</translation>
    </message>
    <message>
        <source>Index all file names</source>
        <translation>Індексувати всі назви файлів</translation>
    </message>
    <message>
        <source>Index the names of files for which the contents cannot be identified or processed (no or unsupported mime type). Default true</source>
        <translation>Індексувати також назви файлів, вміст яких не може бути впізнано чи оброблено (невідомий або непідтримуваний тип MIME).  Типово &quot;так&quot;</translation>
    </message>
</context>
<context>
    <name>QtGuiResListPager</name>
    <message>
        <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
        <translation type="obsolete">&lt;p&gt;&lt;b&gt;Не знайдено&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="obsolete">Попередня</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="obsolete">Наступна</translation>
    </message>
    <message>
        <source>Unavailable document</source>
        <translation type="obsolete">Документ недосяжний</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Перегляд</translation>
    </message>
    <message>
        <source>(show query)</source>
        <translation type="obsolete">(показати запит)</translation>
    </message>
</context>
<context>
    <name>RclMain</name>
    <message>
        <source>Indexing in progress: </source>
        <translation>Індексується: </translation>
    </message>
    <message>
        <source>Query results</source>
        <translation>Результати запиту</translation>
    </message>
    <message>
        <source>Query results (sorted)</source>
        <translation type="obsolete">Результати запиту (сортовано)</translation>
    </message>
    <message>
        <source>Advanced search</source>
        <translation type="obsolete">Складний пошук</translation>
    </message>
    <message>
        <source>Sort criteria</source>
        <translation type="obsolete">Критерії пошуку</translation>
    </message>
    <message>
        <source>User interface preferences</source>
        <translation type="obsolete">Налаштування інтерфейсу</translation>
    </message>
    <message>
        <source>Cannot retrieve document info from database</source>
        <translation>Не можу здобути документ з бази даних</translation>
    </message>
    <message>
        <source>Cannot access document file: </source>
        <translation>Не можу прочитати файл: </translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Перегляд</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>Can&apos;t create preview window</source>
        <translation>Не можу створити вікно перегляду</translation>
    </message>
    <message>
        <source>No external viewer configured for mime type </source>
        <translation>Не знаю переглядача для mime-типа </translation>
    </message>
    <message>
        <source>Executing: [</source>
        <translation>Виконую: [</translation>
    </message>
    <message>
        <source>About Recoll</source>
        <translation>Про Recoll</translation>
    </message>
    <message>
        <source>Starting help browser </source>
        <translation type="obsolete">Запускаю перегляд довідки </translation>
    </message>
    <message>
        <source>Document history</source>
        <translation>Історія документів</translation>
    </message>
    <message>
        <source>Document history (sorted)</source>
        <translation type="obsolete">Історія документів (сортована)</translation>
    </message>
    <message>
        <source>History data</source>
        <translation>Дані історії</translation>
    </message>
    <message>
        <source>Query details</source>
        <translation type="obsolete">Деталі запиту</translation>
    </message>
    <message>
        <source>Files</source>
        <translation>Файли</translation>
    </message>
    <message>
        <source>Purge</source>
        <translation>Очистити</translation>
    </message>
    <message>
        <source>Stemdb</source>
        <translation>База коренів</translation>
    </message>
    <message>
        <source>Closing</source>
        <translation>Закриваю</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Невідомо</translation>
    </message>
    <message>
        <source>This search is not active any more</source>
        <translation>Цей пошук вже неактивний</translation>
    </message>
    <message>
        <source>Cant start query: </source>
        <translation type="obsolete">Неможливо почати запит: </translation>
    </message>
    <message>
        <source>Bad viewer command line for %1: [%2]
Please check the mimeconf file</source>
        <translation>Невірний командний рядок для переглядача %1: [%2]
Перевірте файл mimeconf</translation>
    </message>
    <message>
        <source>The viewer specified in mimeconf for %1: %2 is not found.
Do you want to start the  preferences dialog ?</source>
        <translation>Не знайдено вказаний в mimeconf для %1 переглядач %2.
Відкрити діалог налаштувань?</translation>
    </message>
    <message>
        <source>Cannot extract document or create temporary file</source>
        <translation>Неможливо здобути документ чи створити тимчасовий файл</translation>
    </message>
    <message>
        <source>(no stemming)</source>
        <translation>(без словоформ)</translation>
    </message>
    <message>
        <source>(all languages)</source>
        <translation>(всі мови)</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>помилка здобування списку мов</translation>
    </message>
    <message>
        <source>Update &amp;Index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indexing interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop &amp;Indexing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t start query: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>media</source>
        <translation type="unfinished">мультимедіа</translation>
    </message>
    <message>
        <source>message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>other</source>
        <translation type="unfinished">інше</translation>
    </message>
    <message>
        <source>presentation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sorted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>filtered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>External applications/commands needed and not found for indexing your file types:

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No helpers found missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing helper programs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save file dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose a file name to save under</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RclMainBase</name>
    <message>
        <source>Recoll</source>
        <translation>Recoll</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Інструменти</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Налаштування</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Довідка</translation>
    </message>
    <message>
        <source>Search tools</source>
        <translation>Інструменти пошуку</translation>
    </message>
    <message>
        <source>Result list</source>
        <translation>Список результатів</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="obsolete">Вихід</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Вихід</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Start Indexing</source>
        <translation type="obsolete">Почати індексування</translation>
    </message>
    <message>
        <source>Start &amp;Indexing</source>
        <translation type="obsolete">&amp;Почати індексування</translation>
    </message>
    <message>
        <source>About Recoll</source>
        <translation type="obsolete">Про Recoll</translation>
    </message>
    <message>
        <source>&amp;About Recoll</source>
        <translation>Про &amp;Recoll</translation>
    </message>
    <message>
        <source>User manual</source>
        <translation type="obsolete">Довідник користувача</translation>
    </message>
    <message>
        <source>&amp;User manual</source>
        <translation>&amp;Довідник користувача</translation>
    </message>
    <message>
        <source>Document &amp;History</source>
        <translation>&amp;Історія документів</translation>
    </message>
    <message>
        <source>Document  History</source>
        <translation>Історія документів</translation>
    </message>
    <message>
        <source>Advanced Search</source>
        <translation type="obsolete">Складний пошук</translation>
    </message>
    <message>
        <source>&amp;Advanced Search</source>
        <translation>&amp;Складний пошук</translation>
    </message>
    <message>
        <source>Advanced/complex  Search</source>
        <translation>Складний (поглиблений) пошук</translation>
    </message>
    <message>
        <source>&amp;Sort parameters</source>
        <translation>&amp;Параметри сортування</translation>
    </message>
    <message>
        <source>Sort parameters</source>
        <translation>Параметри сортування</translation>
    </message>
    <message>
        <source>Next page</source>
        <translation>Наступна сторінка</translation>
    </message>
    <message>
        <source>Next page of results</source>
        <translation>Наступна сторінка результатів</translation>
    </message>
    <message>
        <source>Previous page</source>
        <translation>Попередня сторінка</translation>
    </message>
    <message>
        <source>Previous page of results</source>
        <translation>Попередня сторінка результатів</translation>
    </message>
    <message>
        <source>&amp;Query configuration</source>
        <translation>Конфіґурація &amp;запиту</translation>
    </message>
    <message>
        <source>Update index</source>
        <translation type="obsolete">Поновити індекс</translation>
    </message>
    <message>
        <source>Update &amp;index</source>
        <translation>&amp;Поновити індекс</translation>
    </message>
    <message>
        <source>Term &amp;explorer</source>
        <translation>&amp;Навіґатор термінів</translation>
    </message>
    <message>
        <source>Term explorer tool</source>
        <translation>Інструмент для вивчання термінів</translation>
    </message>
    <message>
        <source>External index dialog</source>
        <translation>Діалог зовнішнього індексу</translation>
    </message>
    <message>
        <source>&amp;Erase document history</source>
        <translation>&amp;Очистити історію документів</translation>
    </message>
    <message>
        <source>First page</source>
        <translation>Перша сторінка</translation>
    </message>
    <message>
        <source>Go to first page of results</source>
        <translation>Перейти до першої сторінки результатів</translation>
    </message>
    <message>
        <source>&amp;Indexing configuration</source>
        <translation>&amp;Конфіґурація індексування</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Show missing helpers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RclResList</name>
    <message>
        <source>Result list</source>
        <translation type="obsolete">Список результатів</translation>
    </message>
    <message>
        <source>Unavailable document</source>
        <translation type="obsolete">Документ недосяжний</translation>
    </message>
    <message>
        <source>Show query details</source>
        <translation type="obsolete">Показати запит</translation>
    </message>
    <message>
        <source>&lt;b&gt;Displaying results starting at index %1 (maximum set size %2)&lt;/b&gt;&lt;/p&gt;
</source>
        <translation type="obsolete">&lt;b&gt;Результати починаючи з %1 (максимально %2)&lt;/b&gt;&lt;/p&gt;
</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="obsolete">&amp;Переглянути</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="obsolete">&amp;Редагувати</translation>
    </message>
    <message>
        <source>&amp;Copy File Name</source>
        <translation type="obsolete">&amp;Копіювати ім&apos;я файлу</translation>
    </message>
    <message>
        <source>Copy &amp;Url</source>
        <translation type="obsolete">Копіювати &amp;Url</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
        <translation type="obsolete">&lt;p&gt;&lt;b&gt;Не знайдено&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&amp;More like this</source>
        <translation type="obsolete">&amp;Інші схожі</translation>
    </message>
    <message>
        <source>Query details</source>
        <translation type="obsolete">Деталі запиту</translation>
    </message>
</context>
<context>
    <name>ResList</name>
    <message>
        <source>Result list</source>
        <translation>Список результатів</translation>
    </message>
    <message>
        <source>Unavailable document</source>
        <translation type="unfinished">Документ недосяжний</translation>
    </message>
    <message>
        <source>Show query details</source>
        <translation type="obsolete">Показати запит</translation>
    </message>
    <message>
        <source>&lt;b&gt;Displaying results starting at index %1 (maximum set size %2)&lt;/b&gt;&lt;/p&gt;
</source>
        <translation type="obsolete">&lt;b&gt;Результати починаючи з %1 (не більше за %2)&lt;/b&gt;&lt;/p&gt;
</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished">Попередня</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished">Наступна</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
        <translation type="unfinished">&lt;p&gt;&lt;b&gt;Не знайдено&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Переглянути</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Редагувати</translation>
    </message>
    <message>
        <source>&amp;Copy File Name</source>
        <translation type="obsolete">&amp;Копіювати ім&apos;я файлу</translation>
    </message>
    <message>
        <source>Copy &amp;Url</source>
        <translation type="obsolete">Копіювати &amp;Url</translation>
    </message>
    <message>
        <source>Find &amp;similar documents</source>
        <translation>Знайти &amp;схожі документи</translation>
    </message>
    <message>
        <source>Query details</source>
        <translation>Деталі запиту</translation>
    </message>
    <message>
        <source>(show query)</source>
        <translation>(показати запит)</translation>
    </message>
    <message>
        <source>Copy &amp;File Name</source>
        <translation>Копіювати &amp;назву файла</translation>
    </message>
    <message>
        <source>P&amp;arent document/folder</source>
        <translation>&amp;Батьківський документ/тека</translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%1-%2&lt;/b&gt; out of at least &lt;b&gt;%3&lt;/b&gt; for </source>
        <translation type="obsolete">Документи &lt;b&gt;%1-%2&lt;/b&gt; з принаймні &lt;b&gt;%3&lt;/b&gt; по </translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%1-%2&lt;/b&gt; for </source>
        <translation type="obsolete">Документи &lt;b&gt;%1-%2&lt;/b&gt; по </translation>
    </message>
    <message>
        <source>Copy &amp;URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>filtered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sorted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document history</source>
        <translation type="unfinished">Історія документів</translation>
    </message>
    <message>
        <source>Save to File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%d-%d&lt;/b&gt; out of at least &lt;b&gt;%d&lt;/b&gt; for </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%d-%d&lt;/b&gt; for </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="unfinished">Перегляд</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SSearch</name>
    <message>
        <source>Any term</source>
        <translation>Будь-яке слово</translation>
    </message>
    <message>
        <source>All terms</source>
        <translation>Усі слова</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Ім&apos;я файлу</translation>
    </message>
    <message>
        <source>Completions</source>
        <translation>Доповнення</translation>
    </message>
    <message>
        <source>Select an item:</source>
        <translation>Оберіть:</translation>
    </message>
    <message>
        <source>Too many completions</source>
        <translation>Занадто багато доповнень</translation>
    </message>
    <message>
        <source>Query language</source>
        <translation>Мова запиту</translation>
    </message>
    <message>
        <source>Bad query string</source>
        <translation>Невірний рядок запиту</translation>
    </message>
    <message>
        <source>Out of memory</source>
        <translation>Недостатньо пам&apos;яті</translation>
    </message>
</context>
<context>
    <name>SSearchBase</name>
    <message>
        <source>SSearchBase</source>
        <translation>SSearchBase</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Стерти</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Erase search entry</source>
        <translation>Стерти вміст рядка запита</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Знайти</translation>
    </message>
    <message>
        <source>Start query</source>
        <translation>Почати запит</translation>
    </message>
    <message>
        <source>Choose type of search: any term, all terms, filename with possible wildcards.</source>
        <translation type="obsolete">Оберіть тип запиту: будь-яке слово, усі слова, ім&apos;я файлу (можливі шаблони).</translation>
    </message>
    <message>
        <source>Enter search terms here</source>
        <translation type="obsolete">Ключові слова</translation>
    </message>
    <message>
        <source>Any term</source>
        <translation type="obsolete">Будь-яке слово</translation>
    </message>
    <message>
        <source>All terms</source>
        <translation type="obsolete">Усі слова</translation>
    </message>
    <message>
        <source>File name</source>
        <translation type="obsolete">Ім&apos;я файлу</translation>
    </message>
    <message>
        <source>Completions</source>
        <translation type="obsolete">Доповнення</translation>
    </message>
    <message>
        <source>Select an item:</source>
        <translation type="obsolete">Оберіть:</translation>
    </message>
    <message>
        <source>Enter search terms here. CTRL-TAB for completions of current term.</source>
        <translation type="obsolete">Введіть слова для пошуку. Ctrl-Tab доповнює поточне.</translation>
    </message>
    <message>
        <source>Enter search terms here. Type ESC SPC for completions of current term.</source>
        <translation>Введіть пошукові слова.  Можна використовувати Esc-пробіл для доповнення.</translation>
    </message>
    <message>
        <source>Choose search type.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchClauseW</name>
    <message>
        <source>SearchClauseW</source>
        <translation></translation>
    </message>
    <message>
        <source>Any of these</source>
        <translation>будь-які слова</translation>
    </message>
    <message>
        <source>All of these</source>
        <translation>усі слова</translation>
    </message>
    <message>
        <source>None of these</source>
        <translation>без цих слів</translation>
    </message>
    <message>
        <source>This phrase</source>
        <translation>фраза</translation>
    </message>
    <message>
        <source>Terms in proximity</source>
        <translation>слова поблизу</translation>
    </message>
    <message>
        <source>File name matching</source>
        <translation>назва файлу</translation>
    </message>
    <message>
        <source>Select the type of query that will be performed with the words</source>
        <translation>Виберіть тип запиту, який буде зроблено по цих словах</translation>
    </message>
    <message>
        <source>Number of additional words that may be interspersed with the chosen ones</source>
        <translation>Кількість додаткових слів, що можуть бути між обраними</translation>
    </message>
</context>
<context>
    <name>SortForm</name>
    <message>
        <source>Sort Criteria</source>
        <translation type="obsolete">Критерії сортування</translation>
    </message>
    <message>
        <source>Sort the</source>
        <translation type="obsolete">Сортувати</translation>
    </message>
    <message>
        <source>most relevant results by:</source>
        <translation type="obsolete">кращі результати за:</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="obsolete">Спаданням</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="obsolete">Скинути</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">Закрити</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Mime type</source>
        <translation>Тип MIME</translation>
    </message>
</context>
<context>
    <name>SortFormBase</name>
    <message>
        <source>Sort Criteria</source>
        <translation>Критерії сортування</translation>
    </message>
    <message>
        <source>Sort the</source>
        <translation>Сортувати</translation>
    </message>
    <message>
        <source>most relevant results by:</source>
        <translation>кращих результатів за:</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation>спаданням</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="obsolete">Скинути</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Застосувати</translation>
    </message>
</context>
<context>
    <name>SpellBase</name>
    <message>
        <source>Term Explorer</source>
        <translation>Навіґатор термінів</translation>
    </message>
    <message>
        <source>&amp;Expand </source>
        <translation>&amp;Розкрити </translation>
    </message>
    <message>
        <source>Alt+E</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрити</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <source>Term</source>
        <translation>Слово</translation>
    </message>
    <message>
        <source>Count</source>
        <translation>Кількість</translation>
    </message>
</context>
<context>
    <name>SpellW</name>
    <message>
        <source>Wildcards</source>
        <translation>Шаблони</translation>
    </message>
    <message>
        <source>Regexp</source>
        <translation>Регвираз</translation>
    </message>
    <message>
        <source>Spelling/Phonetic</source>
        <translation>Напис/звучання</translation>
    </message>
    <message>
        <source>Aspell init failed. Aspell not installed?</source>
        <translation>Не вдалося запустити aspell.  Воно взагалі встановлене?</translation>
    </message>
    <message>
        <source>Aspell expansion error. </source>
        <translation>Помилка розкриття aspell. </translation>
    </message>
    <message>
        <source>Stem expansion</source>
        <translation>Розкриття словоформ</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>помилка здобування списку мов</translation>
    </message>
    <message>
        <source>No expansion found</source>
        <translation>Розкриття не знайдене</translation>
    </message>
</context>
<context>
    <name>UIPrefsDialog</name>
    <message>
        <source>MyDialog</source>
        <translation type="obsolete">MyDialog</translation>
    </message>
    <message>
        <source>User interface</source>
        <translation type="obsolete">Інтерфейс</translation>
    </message>
    <message>
        <source>Number of entries in a result page</source>
        <translation type="obsolete">Кількість результатів на сторінку</translation>
    </message>
    <message>
        <source>Result list font</source>
        <translation type="obsolete">Шрифт списку результатів</translation>
    </message>
    <message>
        <source>Helvetica-10</source>
        <translation type="obsolete">Helvetica-10</translation>
    </message>
    <message>
        <source>Opens a dialog to select the result list font</source>
        <translation type="obsolete">Відкриває діалог вибору шрифту списку результатів</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="obsolete">Скинути</translation>
    </message>
    <message>
        <source>Resets the result list font to the system default</source>
        <translation type="obsolete">Повертає шрифт у типовий системний</translation>
    </message>
    <message>
        <source>HTML help browser</source>
        <translation type="obsolete">Переглядач довідки у HTML</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation type="obsolete">Оберіть файл</translation>
    </message>
    <message>
        <source>Show document type icons in result list</source>
        <translation type="obsolete">Відображати типи документів у списку результатів</translation>
    </message>
    <message>
        <source>Search parameters</source>
        <translation type="obsolete">Параметри пошуку</translation>
    </message>
    <message>
        <source>Stemming language</source>
        <translation type="obsolete">Мова словоутворення</translation>
    </message>
    <message>
        <source>Dynamically build abstracts</source>
        <translation type="obsolete">Динамічно будувати реферати</translation>
    </message>
    <message>
        <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
May be slow for big documents.</source>
        <translation type="obsolete">Чи намагатися будувати реферати для результатів пошуку, використовуючі контекст знайдених слів?
Може працювати повільно для великих документів.</translation>
    </message>
    <message>
        <source>Replace abstracts from documents</source>
        <translation type="obsolete">Заміняти реферати з документів</translation>
    </message>
    <message>
        <source>Do we synthetize an abstract even if the document seemed to have one?</source>
        <translation type="obsolete">Чи робити новий реферат, навіть якщо якийсь вже є в документі?</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Apply changes</source>
        <translation type="obsolete">Застосувати зміни</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Відміна</translation>
    </message>
    <message>
        <source>Discard changes</source>
        <translation type="obsolete">Відмінити зміни</translation>
    </message>
    <message>
        <source>Auto-start simple search on whitespace entry</source>
        <translation type="obsolete">Починати простий пошук при введенні пробілу</translation>
    </message>
    <message>
        <source>Extra Databases</source>
        <translation type="obsolete">Додаткові бази</translation>
    </message>
    <message>
        <source>Add database</source>
        <translation type="obsolete">Додати</translation>
    </message>
    <message>
        <source>Select the xapiandb directory for the  database you want to add, then click Add Database</source>
        <translation type="obsolete">Оберіть теку xapiandb для бази даних, яку бажаєте додати, та натисніть &quot;Додати&quot;</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="obsolete">Перегляд</translation>
    </message>
    <message>
        <source>All extra databases</source>
        <translation type="obsolete">Усі</translation>
    </message>
    <message>
        <source>All known extra databases</source>
        <translation type="obsolete">Усі відомі додаткові бази даних</translation>
    </message>
    <message>
        <source>All ----&gt;</source>
        <translation type="obsolete">Всі -----&gt;</translation>
    </message>
    <message>
        <source>Sel -----&gt;</source>
        <translation type="obsolete">Виб -----&gt;</translation>
    </message>
    <message>
        <source>&lt;----- Sel</source>
        <translation type="obsolete">&lt;----- Виб</translation>
    </message>
    <message>
        <source>&lt;----- All</source>
        <translation type="obsolete">&lt;----- Всі</translation>
    </message>
    <message>
        <source>Active extra databases</source>
        <translation type="obsolete">Активні</translation>
    </message>
    <message>
        <source>Extra databases that will be searched in addition to the main one</source>
        <translation type="obsolete">Додаткові бази даних, по яких проходитиме пошук, окрім загальної</translation>
    </message>
    <message>
        <source>The selected directory does not appear to be a Xapian database</source>
        <translation type="obsolete">Обрана тека не схожа на базу даних Xapian</translation>
    </message>
    <message>
        <source>This is the main/local database!</source>
        <translation type="obsolete">Це загальна база!</translation>
    </message>
    <message>
        <source>The selected directory is already in the database list</source>
        <translation type="obsolete">Обрана тека вже у списку</translation>
    </message>
    <message>
        <source>Select directory holding xapian database (ie: /home/someone/.recoll/xapiandb)</source>
        <translation type="obsolete">Оберіть теку, де є база даних xapian (наприклад, /home/someone/.recoll/xapiandb)</translation>
    </message>
    <message>
        <source>(no stemming)</source>
        <translation type="obsolete">(без словоформ)</translation>
    </message>
    <message>
        <source>The selected directory does not appear to be a Xapian index</source>
        <translation>Обрана тека не схожа на індекс Xapian</translation>
    </message>
    <message>
        <source>This is the main/local index!</source>
        <translation>Це основний/локальний індекс!</translation>
    </message>
    <message>
        <source>The selected directory is already in the index list</source>
        <translation>Обрана тека вже у списку індексів</translation>
    </message>
    <message>
        <source>Select xapian index directory (ie: /home/buddy/.recoll/xapiandb)</source>
        <translation>Оберіть теку із індексом Xapian (наприклад, /home/приятель/.recoll/xapiandb)</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>помилка здобування списку мов</translation>
    </message>
</context>
<context>
    <name>UIPrefsDialogBase</name>
    <message>
        <source>MyDialog</source>
        <translation type="obsolete">MyDialog</translation>
    </message>
    <message>
        <source>User interface</source>
        <translation>Інтерфейс</translation>
    </message>
    <message>
        <source>Number of entries in a result page</source>
        <translation>Кількість результатів на сторінку</translation>
    </message>
    <message>
        <source>Result list font</source>
        <translation>Шрифт списку результатів</translation>
    </message>
    <message>
        <source>Helvetica-10</source>
        <translation>Helvetica-10</translation>
    </message>
    <message>
        <source>Opens a dialog to select the result list font</source>
        <translation>Відкриває діалог вибору шрифту списку результатів</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Скинути</translation>
    </message>
    <message>
        <source>Resets the result list font to the system default</source>
        <translation>Повертає шрифт у типовий системний</translation>
    </message>
    <message>
        <source>HTML help browser</source>
        <translation type="obsolete">Переглядач довідки у HTML</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation type="obsolete">Оберіть файл</translation>
    </message>
    <message>
        <source>Show document type icons in result list.</source>
        <translation type="obsolete">Відображати типи документів у списку результатів.</translation>
    </message>
    <message>
        <source>Auto-start simple search on whitespace entry.</source>
        <translation>Починати простий пошук при введенні пробілу.</translation>
    </message>
    <message>
        <source>Start with advanced search dialog open.</source>
        <translation>Відкривати діалог складного пошуку при старті.</translation>
    </message>
    <message>
        <source>Start with sort dialog open.</source>
        <translation>Відкривати діалог сортування при старті.</translation>
    </message>
    <message>
        <source>Search parameters</source>
        <translation>Параметри пошуку</translation>
    </message>
    <message>
        <source>Stemming language</source>
        <translation>Мова словоформ</translation>
    </message>
    <message>
        <source>Automatically add phrase to simple searchs</source>
        <translation type="obsolete">Автоматично додавати фразу до простого пошуку</translation>
    </message>
    <message>
        <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)].</source>
        <translation type="obsolete">Пошук [rolling stones] (2 terms) буде замінено на [rolling or stones or (rolling phrase 2 stones)].</translation>
    </message>
    <message>
        <source>Dynamically build abstracts</source>
        <translation>Динамічно будувати конспекти</translation>
    </message>
    <message>
        <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
May be slow for big documents.</source>
        <translation>Чи намагатися будувати конспекти для результатів пошуку, використовуючі контекст знайдених слів?
Може працювати повільно для великих документів.</translation>
    </message>
    <message>
        <source>Replace abstracts from documents</source>
        <translation>Заміняти наявні у документах конспекти</translation>
    </message>
    <message>
        <source>Do we synthetize an abstract even if the document seemed to have one?</source>
        <translation>Чи робити новий конспект, навіть якщо якийсь вже є в документі?</translation>
    </message>
    <message>
        <source>Synthetic abstract size (characters)</source>
        <translation>Розмір синтетичного конспекту (у символах)</translation>
    </message>
    <message>
        <source>Synthetic abstract context words</source>
        <translation>Контекстних слів у конспекті</translation>
    </message>
    <message>
        <source>External Indexes</source>
        <translation>Зовнішні індекси</translation>
    </message>
    <message>
        <source>Add index</source>
        <translation>Додати індекс</translation>
    </message>
    <message>
        <source>Select the xapiandb directory for the index you want to add, then click Add Index</source>
        <translation>Оберіть потрібну теку із індексом Xapian та натисніть &quot;Додати індекс&quot;</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Перегляд</translation>
    </message>
    <message>
        <source>All indexes</source>
        <translation type="obsolete">Всі індекси</translation>
    </message>
    <message>
        <source>Indexes currently not used</source>
        <translation type="obsolete">Не використовувані</translation>
    </message>
    <message>
        <source>All ----&gt;</source>
        <translation type="obsolete">Всі -----&gt;</translation>
    </message>
    <message>
        <source>Sel -----&gt;</source>
        <translation type="obsolete">Виб -----&gt;</translation>
    </message>
    <message>
        <source>&lt;----- Sel</source>
        <translation type="obsolete">&lt;----- Виб</translation>
    </message>
    <message>
        <source>&lt;----- All</source>
        <translation type="obsolete">&lt;----- Всі</translation>
    </message>
    <message>
        <source>Active indexes</source>
        <translation type="obsolete">Активні</translation>
    </message>
    <message>
        <source>Indexes that will be searched in addition to the main one</source>
        <translation type="obsolete">Індекси, які будуть використані для пошуку у додаток до основного</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Apply changes</source>
        <translation>Застосувати зміни</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Відміна</translation>
    </message>
    <message>
        <source>Discard changes</source>
        <translation>Відмінити зміни</translation>
    </message>
    <message>
        <source>Result paragraph&lt;br&gt;format string</source>
        <translation>Рядок форматування&lt;br&gt;блоку результатів</translation>
    </message>
    <message>
        <source>Automatically add phrase to simple searches</source>
        <translation>Автоматично додавати фразу до простих пошуків</translation>
    </message>
    <message>
        <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)]. 
This should give higher precedence to the results where the search terms appear exactly as entered.</source>
        <translation>Пошук [rolling stones] (2 слова) буде змінено на [rolling or stones or (rolling phrase 2 stones)]. 
Це може підняти результати, в яких пошукові слова зустрічаються саме в такій послідовності, як в запиті.</translation>
    </message>
    <message>
        <source>Choose external viewer applications</source>
        <translation type="obsolete">Оберіть зовнішні програми перегляду</translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="obsolete">Впорядкувати</translation>
    </message>
    <message>
        <source>User preferences</source>
        <translation>Вподобання</translation>
    </message>
    <message>
        <source>Use desktop preferences to choose document editor.</source>
        <translation>Використовувати налаштування десктопу щодо редактору документів.</translation>
    </message>
    <message>
        <source>External indexes</source>
        <translation>Зовнішні індекси</translation>
    </message>
    <message>
        <source>Toggle selected</source>
        <translation>Переключити вибране</translation>
    </message>
    <message>
        <source>Activate All</source>
        <translation>Включити все</translation>
    </message>
    <message>
        <source>Desactivate All</source>
        <translation type="obsolete">Виключити все</translation>
    </message>
    <message>
        <source>Remove selected</source>
        <translation>Видалити вибране</translation>
    </message>
    <message>
        <source>Remove from list. This has no effect on the disk index.</source>
        <translation>Видалити зі списку.  Не впливає на дисковий індекс.</translation>
    </message>
    <message>
        <source>Defines the format for each result list paragraph. Use qt html format and printf-like replacements:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %I Icon image name&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</source>
        <translation>Визначає формат для кожного блоку списку результатів. Використовуйте html-формат qt та схожі на printf заміни:&lt;br&gt;%A анотація&lt;br&gt; %D дата&lt;br&gt; %I назва піктограми&lt;br&gt; %K ключові слова (якщо є)&lt;br&gt; %L посилання перегляду та редагування&lt;br&gt; %M тип MIME&lt;br&gt; %N кількість результатів&lt;br&gt; %R релевантність&lt;br&gt; %S розмір&lt;br&gt; %T назва&lt;br&gt; %U URL&lt;br&gt;</translation>
    </message>
    <message>
        <source>Remember sort activation state.</source>
        <translation>Запам&apos;ятати стан сортування.</translation>
    </message>
    <message>
        <source>Maximum text size highlighted for preview (megabytes)</source>
        <translation>Максимальний розмір тексту із підсвічуванням (Мб)</translation>
    </message>
    <message>
        <source>Texts over this size will not be highlighted in preview (too slow).</source>
        <translation>Тексти із розміром, більшим за вказаний, не буде підсвічено у попередньому перегляді (повільно).</translation>
    </message>
    <message>
        <source>Highlight color for query terms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deactivate All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prefer Html to plain text for preview.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If checked, results with the same content under different names will only be shown once.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide duplicate results.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose editor applications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewAction</name>
    <message>
        <source>Changing actions with different current values</source>
        <translation>Зміна дій із різними поточними значеннями</translation>
    </message>
</context>
<context>
    <name>ViewActionBase</name>
    <message>
        <source>File type</source>
        <translation>Тип файлу</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Дія</translation>
    </message>
    <message>
        <source>Select one or several file types, then click Change Action to modify the program used to open them</source>
        <translation>Оберіть один або декілька типів файлів, потім натисніть &quot;Змінити дію&quot;, щоб змінити програму для них</translation>
    </message>
    <message>
        <source>Change Action</source>
        <translation>Змінити дію</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>Native Viewers</source>
        <translation>Рідні переглядачі</translation>
    </message>
    <message>
        <source>Select one or several mime types then click &quot;Change Action&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>advsearch</name>
    <message>
        <source>Advanced search</source>
        <translation type="obsolete">Складний пошук</translation>
    </message>
    <message>
        <source>Search for files&lt;br&gt;having all of:</source>
        <translation type="obsolete">Шукати файли,&lt;br&gt;в яких є все з:</translation>
    </message>
    <message>
        <source>All non blank fields will be combined with AND conjunctions</source>
        <translation type="obsolete">Всі непусті поля буде об&apos;єднано за допомогою AND</translation>
    </message>
    <message>
        <source>Any of these words</source>
        <translation type="obsolete">Будь-яке з цих слів</translation>
    </message>
    <message>
        <source>File name matching</source>
        <translation type="obsolete">Пошук по іменах файлів</translation>
    </message>
    <message>
        <source>None of these words</source>
        <translation type="obsolete">Жодне з цих слів</translation>
    </message>
    <message>
        <source>All these words</source>
        <translation type="obsolete">Всі ці слова</translation>
    </message>
    <message>
        <source>This exact phrase</source>
        <translation type="obsolete">Точна фраза</translation>
    </message>
    <message>
        <source>Restrict file types</source>
        <translation type="obsolete">Обмежити типи файлів</translation>
    </message>
    <message>
        <source>Searched file types</source>
        <translation type="obsolete">Шукати в файлах типу</translation>
    </message>
    <message>
        <source>All ----&gt;</source>
        <translation type="obsolete">Всі -----&gt;</translation>
    </message>
    <message>
        <source>Sel -----&gt;</source>
        <translation type="obsolete">Виб -----&gt;</translation>
    </message>
    <message>
        <source>&lt;----- Sel</source>
        <translation type="obsolete">&lt;----- Виб</translation>
    </message>
    <message>
        <source>&lt;----- All</source>
        <translation type="obsolete">&lt;----- Всі</translation>
    </message>
    <message>
        <source>Ignored file types</source>
        <translation type="obsolete">Ігнорувати файли типу</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="obsolete">Перегляд</translation>
    </message>
    <message>
        <source>Restrict results to files in subtree:</source>
        <translation type="obsolete">Обмежити пошук по файлах з піддерева:</translation>
    </message>
    <message>
        <source>Start Search</source>
        <translation type="obsolete">Шукати</translation>
    </message>
    <message>
        <source>Dismiss</source>
        <translation type="obsolete">Відмінити</translation>
    </message>
    <message>
        <source>Cannot execute pure negative query. Please enter common terms in the &apos;any words&apos; field</source>
        <translation type="obsolete">Неможна виконати суцільно негативний запит.  Будь ласка, введіть загальні терміни у полі &quot;будь-які слова&quot;</translation>
    </message>
</context>
<context>
    <name>confgui::ConfIndexW</name>
    <message>
        <source>Can&apos;t write configuration file</source>
        <translation>Неможливо записати файл конфіґурації</translation>
    </message>
</context>
<context>
    <name>confgui::ConfParamFNW</name>
    <message>
        <source>Browse</source>
        <translation>Перегляд</translation>
    </message>
</context>
<context>
    <name>confgui::ConfParamSLW</name>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
</context>
<context>
    <name>confgui::ConfSubPanelW</name>
    <message>
        <source>Global</source>
        <translation>Глобальні</translation>
    </message>
    <message>
        <source>Max. compressed file size (KB)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This value sets a threshold beyond which compressedfiles will not be processed. Set to -1 for no limit, to 0 for no decompression ever.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>confgui::ConfTopPanelW</name>
    <message>
        <source>Top directories</source>
        <translation>Верхні теки</translation>
    </message>
    <message>
        <source>The list of directories where recursive indexing starts. Default: your home.</source>
        <translation>Список тек, з яких починається рекурсивне індексування. Типово: домашня тека.</translation>
    </message>
    <message>
        <source>Skipped paths</source>
        <translation>Пропускати шляхи</translation>
    </message>
    <message>
        <source>These are names of directories which indexing will not enter.&lt;br&gt; May contain wildcards. Must match the paths seen by the indexer (ie: if topdirs includes &apos;/home/me&apos; and &apos;/home&apos; is actually a link to &apos;/usr/home&apos;, a correct skippedPath entry would be &apos;/home/tmp*&apos;, not &apos;/usr/home/tmp*&apos;)</source>
        <translation type="obsolete">Це назви тек, у які індексування не потрапить.&lt;br&gt; Може містити шаблони.  Має співпадати із шляхами, що бачить індексатор (наприклад, якщо topdirs містить  &apos;/home/me&apos; та &apos;/home&apos; є посиланням на &apos;/usr/home&apos;, то вірний запис буде &apos;/home/me/tmp*&apos;, а не &apos;/usr/home/me/tmp*&apos;)</translation>
    </message>
    <message>
        <source>Stemming languages</source>
        <translation>Мови зі словоформами</translation>
    </message>
    <message>
        <source>The languages for which stemming expansion&lt;br&gt;dictionaries will be built.</source>
        <translation>Мови, для яких буде побудовано&lt;br&gt;словники розкриття словоформ.</translation>
    </message>
    <message>
        <source>Log file name</source>
        <translation>Файл журналу</translation>
    </message>
    <message>
        <source>The file where the messages will be written.&lt;br&gt;Use &apos;stderr&apos; for terminal output</source>
        <translation>Файл, куди підуть повідомлення.&lt;br&gt;&apos;stderr&apos; для терміналу</translation>
    </message>
    <message>
        <source>Log verbosity level</source>
        <translation>Докладність журналу</translation>
    </message>
    <message>
        <source>This value adjusts the amount of messages,&lt;br&gt;from only errors to a lot of debugging data.</source>
        <translation>Встановити обсяг повідомлень,&lt;br&gt;від помилок до даних зневадження.</translation>
    </message>
    <message>
        <source>Index flush megabytes interval</source>
        <translation>Інтервал скидання індексу (Мб)</translation>
    </message>
    <message>
        <source>This value adjust the amount of data which is indexed betweeen flushes to disk.&lt;br&gt;This helps control the indexer memory usage. Default 10MB </source>
        <translation type="obsolete">Скільки даних буде проіндексовано між скиданнями індексу на диск.&lt;br&gt;Допомагає контролювати використання пам&apos;яті індексатором. Типово: 10Мб </translation>
    </message>
    <message>
        <source>Max disk occupation (%)</source>
        <translation>Максимальне використання диску (%)</translation>
    </message>
    <message>
        <source>This is the percentage of disk occupation where indexing will fail and stop (to avoid filling up your disk).&lt;br&gt;0 means no limit (this is the default).</source>
        <translation>Відсоток зайнятого диску, коли індексування буде зупинено (щоб уникнути заповнення доступного простору).&lt;br&gt;Типово: 0 (без ліміту).</translation>
    </message>
    <message>
        <source>No aspell usage</source>
        <translation>Не використовувати aspell</translation>
    </message>
    <message>
        <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful is aspell is absent or does not work. </source>
        <translation type="obsolete">Вимикає використання aspell для генерації наближень у написання в навіґаторі термінів.&lt;br&gt;Корисне, коли aspell відсутній або зламаний. </translation>
    </message>
    <message>
        <source>Aspell language</source>
        <translation>Мова aspell</translation>
    </message>
    <message>
        <source>The language for the aspell dictionary. This should look like &apos;en&apos; or &apos;fr&apos; ...&lt;br&gt;If this value is not set, the NLS environment will be used to compute it, which usually works.To get an idea of what is installed on your system, type &apos;aspell config&apos; and look for .dat files inside the &apos;data-dir&apos; directory. </source>
        <translation>Мова словника aspell.  Має виглядати як &apos;en&apos; або &apos;uk&apos;...&lt;br&gt;Якщо не встановлене, буде використане оточення (локаль), що зазвичай робить. Щоб з&apos;ясувати, що маємо на системі, наберіть &apos;aspell config&apos; та перегляньте файли .dat у теці &apos;data-dir&apos;. </translation>
    </message>
    <message>
        <source>Database directory name</source>
        <translation>Тека бази даних</translation>
    </message>
    <message>
        <source>The name for a directory where to store the index&lt;br&gt;A non-absolute path is taken relative to the  configuration directory. The default is &apos;xapiandb&apos;.</source>
        <translation>Назва теки, де міститься індекс&lt;br&gt;Відносний шлях буде трактовано відносно теки конфіґурації. Типово: &apos;xapiandb&apos;.</translation>
    </message>
    <message>
        <source>Use system&apos;s &apos;file&apos; command</source>
        <translation>Використовувати системну &apos;file&apos;</translation>
    </message>
    <message>
        <source>Use the system&apos;s &apos;file&apos; command if internal&lt;br&gt;mime type identification fails.</source>
        <translation>Використовувати команду &apos;file&apos; з системи, коли внутрішнє&lt;br&gt;визначення типу MIME дає збій.</translation>
    </message>
    <message>
        <source>These are names of directories which indexing will not enter.&lt;br&gt; May contain wildcards. Must match the paths seen by the indexer (ie: if topdirs includes &apos;/home/me&apos; and &apos;/home&apos; is actually a link to &apos;/usr/home&apos;, a correct skippedPath entry would be &apos;/home/me/tmp*&apos;, not &apos;/usr/home/me/tmp*&apos;)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This value adjust the amount of data which is indexed between flushes to disk.&lt;br&gt;This helps control the indexer memory usage. Default 10MB </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful if aspell is absent or does not work. </source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
